Keen | Sticky Action Bars
Description: Sticky action bar examples

# Customer Relationship Management

New Order

### Sticky Action Bars

Reports

### Sticky Action Bar

Back

### Customer Info:

First Name
Last Name
Company Name
If you want your invoices addressed to a company. Leave blank to use your full name.
Contact Phone
We'll never share your email with anyone else.
Email Address
Company Site
.com

### Address Details:

Country
Address Line 1
Address Line 2
City
State / Province / Region
Zip / Postal Code
Use as shipping address.

### Account:

Username
Email Address
Email will not be publicly displayed. Learn more.
Language
Time Zone
Communication
Email SMS Phone

### Security:

Login verification
After you log in, you will be asked for additional information to confirm your identity and protect your account from being compromised. Learn more.
Password reset verification
Require personal information to reset your password.
For extra security, this requires you to confirm your email or phone number when you reset your password. Learn more.

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!